;+
;
;
;                      Tropospheric Emission
;                          Spectrometer
;                             (TES)
;
;                         Copyright 2005,
;              California Institute of Technology.
;                       ALL RIGHTS RESERVED.
;           U.S. Government Sponsorship acknowledged.
;
;
;
; read_l1b_hdf_geo
;
; PURPOSE:
;	Read TES L1B Geolocation data from L1B HDF product files
;	(version F02,F03)
;
; CALL:
;	 read_l1b_hdf_geo,file,filter,data,status=status
;
; INPUTS:
;	file = name of file to be read (string)
; 	filter = name of filter subset to read (string)
;
; OUTPUTS:
;	data = L1B Geolocation data, an
;		array (number of elements equals number of
;		observations) of structures.  The structures have
;		the following fields:
;
;   TIME_OF_GEOLOCATION		DOUBLE
;   GEOLOCATION_FAILED		BYTE   
;   ORBITASCENDINGFLAG		BYTE    
;   PATH_NUMBER    		BYTE     
;   PCS_QA_POOR_PERCENTAGE	BYTE       
;   DPREP_QA_POOR_PERCENTAGE	BYTE       
;   ORBIT_INCLINATION_ANGLE	DOUBLE        
;   LATITUDE        		DOUBLE        
;   LONGITUDE       		DOUBLE       
;   ELEVATION       		FLOAT         
;   HORIZONTAL_UNCERTAINTY	FLOAT        
;   ELEVATION_UNCERTAINTY	FLOAT        
;   LATITUDE_FOOTPRINT_1	DOUBLE        
;   LATITUDE_FOOTPRINT_2	DOUBLE       
;   LATITUDE_FOOTPRINT_3	DOUBLE       
;   LATITUDE_FOOTPRINT_4	DOUBLE      
;   LONGITUDE_FOOTPRINT_1	DOUBLE        
;   LONGITUDE_FOOTPRINT_2	DOUBLE        
;   LONGITUDE_FOOTPRINT_3	DOUBLE       
;   LONGITUDE_FOOTPRINT_4	DOUBLE         
;   SURFACEELEVATION		FLOAT        
;   SURFACEELEVSTANDARDDEVIATION FLOAT      
;   MIN_ELEV_FOOTPRINT		FLOAT                     
;   MAX_ELEV_FOOTPRINT		FLOAT     
;   SURFACE_TYPE_FOOTPRINT	BYTE   
;   DAY_NIGHT_FLAG_TARGET	BYTE   
;   DAY_NIGHT_FLAG_SC		BYTE 
;   LOCALSOLARTIME  		FLOAT       
;   TES_BSIGHT_AZIMUTH		DOUBLE         
;   TES_BSIGHT_AZIMUTH_UNCERT	DOUBLE     
;   TESBORESIGHTNADIRANGLE	DOUBLE    
;   TES_BSIGHT_NADIR_UNCERT	DOUBLE    
;   GRD_TRK_TES_BSIGHT_AZIMUTH	DOUBLE     
;   SPACECRAFTAZIMUTH		DOUBLE              
;   SPACECRAFTZENITH		DOUBLE   
;   TGT_SUN_AZIMUTH 		DOUBLE    
;   TGT_SUN_ZENITH_ANGLE	DOUBLE   
;   SOLARAZIMUTHANGLE		DOUBLE  
;   SOLARZENITHANGLE		DOUBLE   
;   M1_MIRROR_SUN_ANGLE		DOUBLE    
;   SPACECRAFTLATITUDE		DOUBLE    
;   SPACECRAFTLONGITUDE		DOUBLE   
;   SPACECRAFTALTITUDE		DOUBLE   
;   DOPPLER_SHIFT   		DOUBLE  
;   RESOLVED_SC_POSITION_X	DOUBLE    
;   RESOLVED_SC_POSITION_Y	DOUBLE    
;   RESOLVED_SC_POSITION_Z	DOUBLE   
;   RESOLVED_SC_VELOCITY_X	DOUBLE  
;   RESOLVED_SC_VELOCITY_Y	DOUBLE  
;   RESOLVED_SC_VELOCITY_Z	DOUBLE  
;   RESOLVED_SC_QUATERNION_Q1	DOUBLE  
;   RESOLVED_SC_QUATERNION_Q2	DOUBLE 
;   RESOLVED_SC_QUATERNION_Q3	DOUBLE 
;   RESOLVED_SC_QUATERNION_Q4	DOUBLE  
;   RESOLVED_SC_ATTITUDE_PITCH	DOUBLE  
;   RESOLVED_SC_ATTITUDE_ROLL	DOUBLE       
;   RESOLVED_SC_ATTITUDE_YAW	DOUBLE 
;   RESOLVED_SC_PITCH_RATE	DOUBLE    
;   RESOLVED_SC_ROLL_RATE	DOUBLE    
;   RESOLVED_SC_YAW_RATE	DOUBLE   
;   PCS_TRACK       		DOUBLE   
;   PCS_CROSSTRACK  		DOUBLE  
;
;	Output data is undefined upon an error condition
;
;
; KEYWORD OUTPUT:
;	status = 0 for success
;		 1 if file does not exist
;		 2 the file name does not have F02_01 in name
;		 3 the file is not HDF 5
; 
; ORIGINAL AUTHOR:
;	Brendan Fisher, JPL, 07/2005
;
; UPDATE HISTORY:
;
;-

;
pro read_l1b_hdf_geo,file,filter,data,status=status

if n_params() ne 3 then begin
    print,'Usage:'
    print,'read_l1b_hdf_geo,file,filter,data,status=status'
    return
endif

status=0

; check for file existence
ff = file_search(file,count=count)
if count eq 0 then begin
    print,'Cannot find file:'
    print,file
    status = 1
    return
endif
;check version
pos2 = strpos(file,'_F02_')
pos3 = strpos(file,'_F03_')
if pos2 ne -1 then version = 2
if pos3 ne -1 then version = 3
pos=0
if pos eq -1 then begin
    print,'Expected version _F02_ or _F03_ in file name not found.'
    print,file
    status = 2
    return
endif
; check to see if file is an HDF5 
if not h5f_is_hdf5(file) then begin
    print,'File is not HDF 5:'
    print,file
    status=3
    return
endif


fid = h5f_open(file)

groupid = h5g_open(fid,'Filter'+strupcase(filter))

id = h5d_open(groupid,'Geolocation')

data = h5d_read(id)

h5d_close,id


h5g_close, groupid
h5f_close,fid



return

end
