;+
;
;
;                      Tropospheric Emission
;                          Spectrometer
;                             (TES)
;
;                         Copyright 2005,
;              California Institute of Technology.
;                       ALL RIGHTS RESERVED.
;           U.S. Government Sponsorship acknowledged.
;
;
;
; read_l1b_hdf_l1bmeta
;
; PURPOSE:
; 	Read TES L1B HDF file for the L1B metadata
;
; CALL:
; 	read_l1b_hdf_l1bmeta,file,data,status=status
;
; INPUTS:
;	file = name of file to be read (string)
;
; OUTPUTS:
;	data = metadata information as a structure
;	with the following fields:
;	       run_counter  (long)
;	       orbital_path_id (byte)
;	       absolute_orbit_number (long)
;	       time_of_observation_start (double)
;	       time_of_observation_end (double)
;	       geolocation_data_missing (integer)
;	       icecontamination (byte)
;	       l1a_data_missing (double)
;	       l1b_data_missing (double)
;	       command_seq_id (long) (V2) (zero for V3)
;
;
; KEYWORD OUTPUT:
;	status = 0 for success
;		 1 if file does not exist
;		 2 the file name does not have F02_01 in name
;		 3 the file is not HDF 5
; 
; ORIGINAL AUTHOR:
;	Brendan Fisher, JPL, 07/2005
;
; UPDATE HISTORY:
;
;-
pro read_l1b_hdf_l1bmeta,file,data,status=status

if n_params() ne 2 then begin
    print,'Usage:'
    print,'read_l1b_hdf_l1bmeta,file,metadata,status=status'
    return
endif

status=0

; check for file existence
ff = file_search(file,count=count)
if count eq 0 then begin
    print,'Cannot find file:'
    print,file
    status = 1
    return
endif
; check version
pos2 = strpos(file,'_F02_')
pos3 = strpos(file,'_F03_')
if pos2 ne -1 then version = 2
if pos3 ne -1 then version = 3
pos=0
if pos eq -1 then begin
    print,'Expected version _F02_ or _F03_ in file name not found.'
    print,file
    status = 2
    return
endif
; check to see if file is an HDF5 
if not h5f_is_hdf5(file) then begin
    print,'File is not HDF 5:'
    print,file
    status=3
    return
endif

fid = h5f_open(file)



subid = h5g_open(fid,'L1B_MetadataGroup')

data = { $
       run_counter : 0l, $
       orbital_path_id : 0b, $
       absolute_orbit_number : 0l, $
       time_of_observation_start : 0.0d, $
       time_of_observation_end : 0.0d, $
       geolocation_data_missing : 0, $
       icecontamination : 0b, $
       l1a_data_missing : 0.0, $
       l1b_data_missing : 0.0, $
       command_seq_id : 0l }

id = h5a_open_name(subid,'Run_Counter')
data.run_counter = h5a_read(id)
h5a_close,id

id = h5a_open_name(subid,'Orbital_Path_ID')
data.orbital_path_id = h5a_read(id)
h5a_close,id

id = h5a_open_name(subid,'Time_Of_Observation_Start')
data.time_of_observation_start = h5a_read(id)
h5a_close,id

id = h5a_open_name(subid,'Time_Of_Observation_End')
data.time_of_observation_end = h5a_read(id)
h5a_close,id

id = h5a_open_name(subid,'Geolocation_Data_Missing')
data.geolocation_data_missing = h5a_read(id)
h5a_close,id

id = h5a_open_name(subid,'IceContamination')
data.icecontamination = h5a_read(id)
h5a_close,id

id = h5a_open_name(subid,'L1A_Data_Missing')
data.l1a_data_missing = h5a_read(id)
h5a_close,id

id = h5a_open_name(subid,'L1B_Data_Missing')
data.l1b_data_missing = h5a_read(id)
h5a_close,id

if version eq 2 then begin
    id = h5a_open_name(subid,'Command_Seq_ID')
    data.command_seq_id = h5a_read(id)
    h5a_close,id
endif else data.command_seq_id = 0




h5g_close,subid
h5f_close,fid


return

end
