;+
;
;
;                      Tropospheric Emission
;                          Spectrometer
;                             (TES)
;
;                         Copyright 2005,
;              California Institute of Technology.
;                       ALL RIGHTS RESERVED.
;           U.S. Government Sponsorship acknowledged.
;
;
;
; read_l1b_hdf_nesr
;
; PURPOSE:
;	Read TES L1B NERS from L1B HDF product files (version F02, F03)
;
; CALL:
;	 read_l1b_hdf_nesr,file,filter,nesr,status=status
;
; INPUTS:
;	file = name of file to be read (string)
; 	filter = name of filter subset to read (string)
;
; OUTPUTS:
;	nesr = L1B nesr, LxMxN array (float), L spectral points,
;		M observations, N detectors
;		(note: spectral scale can be obtained with
;		read_l1b_hdf_spectra)
;
; KEYWORD OUTPUT:
;	status = 0 for success
;		 1 if file does not exist
;		 2 the file name does not have F02_01 in name
;		 3 the file is not HDF 5
; 
; ORIGINAL AUTHOR:
;	Brendan Fisher, JPL, 07/2005
;
; UPDATE HISTORY:
;
;-

pro read_l1b_hdf_nesr,file,filter,nesr,status=status

if n_params() ne 3 then begin
    print,'Usage:'
    print,'read_l1b_hdf_nesr,file,filter,nesr,status=status'
    return
endif

status=0
; check for file existence
ff = file_search(file,count=count)
if count eq 0 then begin
    print,'Cannot find file:'
    print,file
    status = 1
    return
endif
; check version
pos2 = strpos(file,'_F02_')
pos3 = strpos(file,'_F03_')
if pos2 ne -1 then version = 2
if pos3 ne -1 then version = 3
pos=0
if pos eq -1 then begin
    print,'Expected version _F02 or _F03_ in file name not found.'
    print,file
    status = 2
    return
endif
; check to see if file is an HDF5 
if not h5f_is_hdf5(file) then begin
    print,'File is not HDF 5:'
    print,file
    status=3
    return
endif


fid = h5f_open(file)

groupid = h5g_open(fid,'Filter'+strupcase(filter))

id = h5d_open(groupid,'NESR')

nesr = h5d_read(id)

h5d_close,id


h5g_close, groupid
h5f_close,fid


return

end
